import _extends from "@babel/runtime/helpers/extends";
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import { useIsomorphicLayoutEffect } from '../shared/use-isomorphic-layout-effect';
import { classNames, getExtraAttrs } from '../shared/utils';
import { colorClasses } from '../shared/mixins';


var Tabs = /*#__PURE__*/forwardRef(function (props, ref) {
  var className = props.className,
      id = props.id,
      style = props.style,
      children = props.children,
      animated = props.animated,
      swipeable = props.swipeable,
      routable = props.routable,
      swiperParams = props.swiperParams;
  var extraAttrs = getExtraAttrs(props);
  var elRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      el: elRef.current
    };
  });
  useIsomorphicLayoutEffect(function () {
    if (!swipeable || !swiperParams) return;
    if (!elRef.current) return;
    elRef.current.zmpSwiperParams = swiperParams;
  }, []);
  var classes = classNames(className, colorClasses(props));
  var wrapClasses = classNames({
    'tabs-animated-wrap': animated,
    'tabs-swipeable-wrap': swipeable
  });
  var tabsClasses = classNames({
    tabs: true,
    'tabs-routable': routable
  });

  if (animated || swipeable) {
    return /*#__PURE__*/React.createElement("div", _extends({
      id: id,
      style: style,
      className: classNames(wrapClasses, classes),
      ref: elRef
    }, extraAttrs), /*#__PURE__*/React.createElement("div", {
      className: tabsClasses
    }, children));
  }

  return /*#__PURE__*/React.createElement("div", _extends({
    id: id,
    style: style,
    className: classNames(tabsClasses, classes),
    ref: elRef
  }, extraAttrs), children);
});
Tabs.displayName = 'zmp-tabs';
export default Tabs;